
# Change Log
All notable changes to this project will be documented in this file.
 
The format is based on [Keep a Changelog](http://keepachangelog.com/)
and this project adheres to [Semantic Versioning](http://semver.org/).
 
## [Unreleased] - yyyy-mm-dd

## [0.2.3] - 2022-03-22

### Changes
- Project data

## [0.2.2] - 2022-03-22

### Added
- Data validation for response classes
- Static rules response class
